/*
** pork_imwindow.h - interface for manipulating conversation/chat/info windows.
** Copyright (C) 2002-2003 Ryan McCabe <ryan@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
*/

#ifndef __PORK_IMWINDOW_H
#define __PORK_IMWINDOW_H

#define IMWINDOW(x)	((struct imwindow *) (x))

#define TYPE_STATUS		0
#define TYPE_IM			1
#define TYPE_CHAT		2

#define FOCUS_MSG		0
#define FOCUS_BUDDY		1

struct chatroom;

struct imwindow {
	struct swindow swindow;
	struct input *input;
	struct aim_priv *priv;
	struct key_binds *active_binds;
	char *target;
	char *name;
	u_int32_t refnum;
	u_int32_t typing:2;
	u_int32_t blist_visible:1;
	u_int32_t input_focus:1;
	u_int32_t type:2;
	struct chatroom *chat;
	struct window_opts opts[WOPT_NUM_OPTS];
};

struct imwindow *imwindow_new(	u_int32_t rows,
								u_int32_t cols,
								u_int32_t refnum,
								u_int32_t type,
								struct aim_priv *priv,
								char *target);

void imwindow_resize(	struct imwindow *imwindow,
						u_int32_t rows,
						u_int32_t cols);

int imwindow_set_priv_input(struct imwindow *imwindow, int val);
int imwindow_blist_refresh(struct imwindow *imwindow);
void imwindow_blist_show(struct imwindow *imwindow);
void imwindow_blist_hide(struct imwindow *imwindow);
void imwindow_blist_draw(struct imwindow *imwindow);

int imwindow_bind_acct(struct imwindow *imwindow, char *user);
void imwindow_recv_im(struct imwindow *w, const char *src, int autor ,const char *msg);
int imwindow_refresh(struct imwindow *imwindow);
void imwindow_destroy(struct imwindow *imwindow);
void imwindow_switch_focus(struct imwindow *imwindow);
void imwindow_send_im(struct imwindow *imwindow, char *str);
void imwindow_buffer_find(struct imwindow *imwindow, char *str, u_int32_t opt);

struct imwindow *imwindow_find_refnum(u_int32_t refnum);
struct imwindow *imwindow_find(struct aim_priv *owner, const char *target);
struct imwindow *imwindow_find_name(struct aim_priv *owner, const char *name);
struct imwindow *imwindow_find_chat_target(	struct aim_priv *owner,
											const char *target);

inline void imwindow_rename(struct imwindow *imwindow, char *new_name);
inline void imwindow_scroll_up(struct imwindow *imwindow);
inline void imwindow_scroll_down(struct imwindow *imwindow);
inline void imwindow_scroll_by(struct imwindow *imwindow, int lines);
inline void imwindow_scroll_page_up(struct imwindow *imwindow);
inline void imwindow_scroll_page_down(struct imwindow *imwindow);
inline void imwindow_scroll_start(struct imwindow *imwindow);
inline void imwindow_scroll_end(struct imwindow *imwindow);
inline void imwindow_clear(struct imwindow *imwindow);
inline void imwindow_erase(struct imwindow *imwindow);

#endif
